"""Common configuration constants
"""

PROJECTNAME = 'collective.salesforce.query'

ADD_PERMISSIONS = {
    # -*- extra stuff goes here -*-
    'SalesforceQuery': 'collective.salesforce.query: Add SalesforceQuery',
}
